export { l as loadWasm } from './types/index.mjs';
import { ThemeInput, LanguageInput, CodeToHtmlOptions } from './types.mjs';
export { Awaitable, BuiltinLanguages, BuiltinThemes, ElementsOptions, HtmlRendererOptions, LanguageRegistration, LineOption, MaybeGetter, ThemeRegisteration, ThemeRegisterationRaw } from './types.mjs';

/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/

interface WebAssemblyInstantiator {
	(importObject: Record<string, Record<string, WebAssembly.ImportValue>> | undefined): Promise<WebAssembly.WebAssemblyInstantiatedSource>;
}
interface ICommonOptions {
	print?(str: string): void;
}
interface IInstantiatorOptions extends ICommonOptions {
	instantiator: WebAssemblyInstantiator;
}
interface IDataOptions extends ICommonOptions {
	data: ArrayBuffer | Response;
}
type IOptions = IInstantiatorOptions | IDataOptions;

interface CoreHighlighterOptions {
    themes: ThemeInput[];
    langs: LanguageInput[];
    loadWasm?: IOptions | (() => Promise<IOptions>);
}

declare function getHighlighter(options: CoreHighlighterOptions): Promise<{
    codeToThemedTokens: (code: string, lang?: string, theme?: string, options?: {
        includeExplanation: boolean;
    }) => {
        content: string;
    }[][];
    codeToHtml: (code: string, options?: CodeToHtmlOptions) => string;
}>;

export { CodeToHtmlOptions, CoreHighlighterOptions, LanguageInput, ThemeInput, getHighlighter };
